==> freeciv_3.0.6.orig.tar.xz: freeciv-3.0.6/client/gui-stub/optiondlg.c <==
/********************************************************************** 
 Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/

#ifdef HAVE_CONFIG_H
#include <fc_config.h>
#endif

/* utility */
#include "log.h"

/* gui main header */
#include "gui_stub.h"

#include "optiondlg.h"


/****************************************************************************
  Popup the option dialog for the option set.
  FIXME/PORTME
****************************************************************************/
void option_dialog_popup(const char *name, const struct option_set *poptset)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/****************************************************************************
  Popdown the option dialog for the option set.
  FIXME/PORTME
****************************************************************************/
void option_dialog_popdown(const struct option_set *poptset)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/****************************************************************************
  Update the GUI for the option.
  FIXME/PORTME
****************************************************************************/
void option_gui_update(struct option *poption)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/****************************************************************************
  Add the GUI for the option.
  FIXME/PORTME
****************************************************************************/
void option_gui_add(struct option *poption)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/****************************************************************************
  Remove the GUI for the option.
  FIXME/PORTME
****************************************************************************/
void option_gui_remove(struct option *poption)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

==> freeciv-3.1.5.tar.xz: freeciv-3.1.5/client/gui-stub/optiondlg.c <==
/***********************************************************************
 Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/

#ifdef HAVE_CONFIG_H
#include <fc_config.h>
#endif

/* utility */
#include "log.h"

/* gui main header */
#include "gui_stub.h"

#include "optiondlg.h"


/************************************************************************//**
  Popup the option dialog for the option set.
  FIXME/PORTME
****************************************************************************/
void option_dialog_popup(const char *name, const struct option_set *poptset)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/************************************************************************//**
  Popdown the option dialog for the option set.
  FIXME/PORTME
****************************************************************************/
void option_dialog_popdown(const struct option_set *poptset)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/************************************************************************//**
  Update the GUI for the option.
  FIXME/PORTME
****************************************************************************/
void option_gui_update(struct option *poption)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/************************************************************************//**
  Add the GUI for the option.
  FIXME/PORTME
****************************************************************************/
void option_gui_add(struct option *poption)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}

/************************************************************************//**
  Remove the GUI for the option.
  FIXME/PORTME
****************************************************************************/
void option_gui_remove(struct option *poption)
{
  log_error("%s(): PORTME!", __FUNCTION__);
}
